==> haskell-retry-0.7.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-retry/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.1
id: retry-0.7.1-a46527ed45a408ee5213d2b1d44137c7
key: retry_Fsk9QqrlVmB5UP75qGd5r9
license: BSD3
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
author: Ozgun Ataman
exposed: True
exposed-modules:
    Control.Retry
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/retry-0.7.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/retry-0.7.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/retry-0.7.1
hs-libraries: HSretry-0.7.1-Fsk9QqrlVmB5UP75qGd5r9
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retry-0.7.2-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-retry/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.2
id: retry-0.7.2-41dba78052d95adc66e58e22ad31c75f
key: retry_6FeOPhtStZgE3urQtlBpvl
license: BSD3
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
author: Ozgun Ataman
exposed: True
exposed-modules:
    Control.Retry
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/retry-0.7.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/retry-0.7.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/retry-0.7.2
hs-libraries: HSretry-0.7.2-6FeOPhtStZgE3urQtlBpvl
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
